@@ -9,30 +9,17 @@ class TrayIcon:
 
     def __init__(self):
 
-        from utils.systray import Icon as SysTrayIcon
-
-        self.__trayicon = SysTrayIcon("gDesklets")
-
-        pixbuf = gtk.gdk.pixbuf_new_from_file(ICON)
-        pixbuf = pixbuf.scale_simple(24, 24, gtk.gdk.INTERP_HYPER)
-
-        icon = gtk.Image()
-        icon.set_from_pixbuf(pixbuf)
-
-        self.__ebox = gtk.EventBox()
-        self.__ebox.add(icon)
-        self.__ebox.show_all()
-        self.__trayicon.add(self.__ebox)
-
         self.__menu = gtk.Menu()
 
-        self.__ebox.connect("button-press-event", self.__on_button)
+        self.__trayicon = gtk.status_icon_new_from_file(ICON)
+        self.__trayicon.connect("popup-menu", self.__on_button)
 
 
-    def __on_button(self, src, event):
 
-        if (event.button == 3):
-            self.__menu.popup(None, None, None, event.button, event.time)
+    def __on_button(self, widget, button, time):
+
+        if (button == 3):
+            self.__menu.popup(None, None, None, button, time)
 
 
     def set_menu(self, items):
@@ -55,7 +42,3 @@ class TrayIcon:
             item.show()
             self.__menu.append(item)
 
-
-    def connect(self, event, *args):
-
-        self.__ebox.connect(event, *args)
