@@ -1,37 +1,21 @@
 import os
 import sys
 import utils
-import __builtin__
 from utils import vfs
 
 
-if (sys.platform == "win32"):
-    HAVE_WIN32 = True
-else:
-    # no, we're lucky
-    HAVE_WIN32 = False
-
-__builtin__.HAVE_WIN32 = HAVE_WIN32
-
 # gDesklets home paths
 HOME = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir))
-if (HAVE_WIN32):
-    USERHOME = os.path.join(os.environ["APPDATA"], "gDesklets")
-else:
-    USERHOME = os.path.join(os.path.expanduser("~"), ".gdesklets")
+USERHOME = os.path.join(os.path.expanduser("~"), ".gdesklets")
 OLDHOME = os.path.join(HOME, os.pardir, os.pardir, "share", "gdesklets")
 
-
 # we need the DISPLAY variable
-if (HAVE_WIN32):
-    DISPLAY = "win32"
-else:
-    try:
-        DISPLAY = vfs.escape_path(os.environ["DISPLAY"].replace("/", "_"))
-    except KeyError:
-        print "The DISPLAY variable is NOT set, which usually means, " \
-              "that X isn't running!"
-        sys.exit(1)
+try:
+    DISPLAY = vfs.escape_path(os.environ["DISPLAY"].replace("/", "_"))
+except KeyError:
+    print "The DISPLAY variable is NOT set, which usually means, " \
+          "that X isn't running!"
+    sys.exit(1)
 
 
 # the name of the purge key
@@ -69,8 +53,8 @@ _ = Translator("gdesklets")
 
 
 NAME = "gDesklets"
-VERSION = "0.35.3"
-COPYRIGHT = u"Copyright \xa9 2003 - 2006 The gDesklets Team"
+VERSION = "0.36"
+COPYRIGHT = u"Copyright \xa9 2003 - 2008 The gDesklets Team"
 DESCRIPTION = _("A desktop applet system for GNOME")
 AUTHORS = ( "Martin Grimme <martin@pycage.de>",
             "Christian Meyer <chrisime@gnome-de.org>",
@@ -78,49 +62,42 @@ AUTHORS = ( "Martin Grimme <martin@pycage.de>",
            u"S\xe9bastien Bacher <seb128@debian.org>",
            u"Beno\xeet Dejean <tazforever@dlfp.org>"
           )
-DOCUMENTERS = ("Martin Grimme <martin@pycage.de>",)
+DOCUMENTERS = ("Martin Grimme <martin@pycage.de>",
+               "Joe Sapp <nixphoeni@yahoo.com>",
+               "Bjoern Koch <H.Humpel@gmx.de>",
+               u"Robert Pastierovi\u010d <pastierovic@gmail.com>",)
 ICON = os.path.join(HOME, "data", "gdesklets.png")
 CREDITS = (
            (_("Version %s") % (VERSION,),
-           (u"Copyright \xa9 2003 - 2006", "The gDesklets Team")),
+           (u"Copyright \xa9 2003 - 2008", "The gDesklets Team")),
 
            (_("Core Programming:"),
-           ("Martin Grimme", "Christian Meyer", "Jesse Andrews",
-            u"Beno\xeet Dejean")),
+           ("Martin Grimme", "Christian Meyer", "Jesse Andrews", u"Beno\xeet Dejean",)),
 
            (_("Architecture Design:"),
-           ("Martin Grimme", "Christian Meyer")),
+           ("Martin Grimme", "Christian Meyer",)),
 
            (_("GNOME Integration:"),
-           ("Christian Neumair", "Martin Grimme", u"S\xe9bastien Bacher",
-            "Christian Kellner", "Christian Meyer")),
+           ("Christian Neumair", "Martin Grimme", u"S\xe9bastien Bacher", "Christian Kellner", "Christian Meyer",)),
+
+           (_("Additional programming:"),
+           ("Bjoern Koch", u"Robert Pastierovi\u010d",)),
+
+           (_("Documentation:"),
+           ("Martin Grimme", "Joe Sapp", "Bjoern Koch", u"Robert Pastierovi\u010d",)),
 
            (_("Artwork:"),
            ("Johannes Rebhan",)),
 
            (_("Website:"),
-           ("Marius M.M.", "Luke Stroven (previous site)",)),
+           ("Lauri Kainulainen", "Marius M.M.", "Luke Stroven (previous site)",)),
 
            (_("Thank you:"),
            ("VidaLinux for sponsoring",
-            "the http://www.gdesklets.org domain!",))
+            "the http://www.gdesklets.org domain!",
+            "LinuxProfessionals for sponsoring",
+            "webspace and the",
+            "http://www.gdesklets.de domain!",)
+           )
           )
 
-
-def init():
-
-    """ gDesklets init process """
-    import signal
-    import gtk
-
-    # prepare GTK for threads
-    try:
-        gtk.threads_init()
-    except:
-        print "No threading support available in python."
-        print "Compile python with --enable-threads. Exiting!"
-        sys.exit(1)
-
-    # install signal handler to quit on Ctrl-C
-    signal.signal(signal.SIGINT, gtk.main_quit)
-
